@@ -11,6 +11,12 @@
 #' @param group.by.colors.use \strong{\code{\link[base]{character}}} | Colors to use for the group dots.
 #' @param group.by.show.dots \strong{\code{\link[base]{logical}}} | Controls whether to place in the middle of the groups.
 #' @param group.by.cell_borders.alpha \strong{\code{\link[base]{numeric}}} | Controls the transparency of the new borders drawn by \strong{\code{group.by.cell_borders}}.
+#' @param symmetry.type \strong{\code{\link[base]{character}}} | Type of symmetry to be enforced. One of:
+#' \itemize{
+#'   \item \emph{\code{absolute}}: The highest absolute value will be taken into a account to generate the color scale. Works after \strong{\code{min.cutoff}} and \strong{\code{max.cutoff}}.
+#'   \item \emph{\code{centered}}: Centers the scale around the provided value in \strong{\code{symmetry.center}}. Works after \strong{\code{min.cutoff}} and \strong{\code{max.cutoff}}.
+#' }
+#' @param symmetry.center \strong{\code{\link[base]{numeric}}} | Value upon which the scale will be centered.
 #' @return  A ggplot2 object containing a Feature Plot.
 #' @export
 #'
@@ -34,6 +40,8 @@ do_FeaturePlot <- function(sample,
                            idents.highlight = NULL,
                            dims = c(1, 2),
                            enforce_symmetry = FALSE,
+                           symmetry.type = "absolute", 
+                           symmetry.center = NA,
                            pt.size = 1,
                            font.size = 14,
                            font.type = "sans",
@@ -93,7 +101,7 @@ do_FeaturePlot <- function(sample,
                            legend.text.face = "plain"){
   # Add lengthy error messages.
   withr::local_options(.new = list("warning.length" = 8170))
-  
+
   check_suggests(function_name = "do_FeaturePlot")
   # Check if the sample provided is a Seurat object.
   check_Seurat(sample = sample)
@@ -101,9 +109,9 @@ do_FeaturePlot <- function(sample,
   out <- check_and_set_assay(sample = sample, assay = assay)
   sample <- out[["sample"]]
   assay <- out[["assay"]]
-  
+
   sample <- check_Assay5(sample, assay = assay)
-  
+
   # Check the reduction.
   reduction <- check_and_set_reduction(sample = sample, reduction = reduction)
   # Check the dimensions.
@@ -144,7 +152,8 @@ do_FeaturePlot <- function(sample,
                        "group.by.dot.size" = group.by.dot.size,
                        "group.by.cell_borders.alpha" = group.by.cell_borders.alpha,
                        "sequential.direction" = sequential.direction,
-                       "diverging.direction" = diverging.direction)
+                       "diverging.direction" = diverging.direction,
+                       "symmetry.center" = symmetry.center)
   check_type(parameters = numeric_list, required_type = "numeric", test_function = is.numeric)
   # Check character parameters.
   # Workaround for features.
@@ -188,7 +197,8 @@ do_FeaturePlot <- function(sample,
                          "axis.title.face" = axis.title.face,
                          "axis.text.face" = axis.text.face,
                          "legend.title.face" = legend.title.face,
-                         "legend.text.face" = legend.text.face)
+                         "legend.text.face" = legend.text.face,
+                         "symmetry.type" = symmetry.type)
   check_type(parameters = character_list, required_type = "character", test_function = is.character)
 
   # Check slot.
@@ -285,7 +295,9 @@ do_FeaturePlot <- function(sample,
   check_parameters(viridis.direction, parameter_name = "viridis.direction")
   check_parameters(sequential.direction, parameter_name = "sequential.direction")
   check_parameters(diverging.direction, parameter_name = "diverging.direction")
-
+  check_parameters(parameter = symmetry.type, parameter_name = "symmetry.type")
+  
+  
   if (length(min.cutoff) != length(features)){
     warning(paste0(add_warning(), crayon_body("Please provide as many values to "),
                    crayon_key("min.cutoff"),
@@ -293,7 +305,7 @@ do_FeaturePlot <- function(sample,
                    crayon_key("features"),
                    crayon_body(" provided. The values will be used in order and, when outside of the range, no cutoffs will be applied.")), call. = FALSE)
   }
-  
+
   if (length(max.cutoff) != length(features)){
     warning(paste0(add_warning(), crayon_body("Please provide as many values to "),
                    crayon_key("max.cutoff"),
@@ -301,7 +313,7 @@ do_FeaturePlot <- function(sample,
                    crayon_key("features"),
                    crayon_body(" provided. The values will be used in order and, when outside of the range, no cutoffs will be applied.")), call. = FALSE)
   }
-  
+
   # Generate the continuous color palette.
   if (isTRUE(enforce_symmetry)){
     colors.gradient <- compute_continuous_palette(name = diverging.palette,
@@ -314,8 +326,8 @@ do_FeaturePlot <- function(sample,
                                                   direction = ifelse(isTRUE(use_viridis), viridis.direction, sequential.direction),
                                                   enforce_symmetry = enforce_symmetry)
   }
-  
-  
+
+
   # Generate base layer.
   if (isTRUE(plot_cell_borders)){
     out <- compute_umap_layer(sample = sample,
@@ -404,7 +416,9 @@ do_FeaturePlot <- function(sample,
                                       min.cutoff = min.cutoff,
                                       max.cutoff = max.cutoff,
                                       flavor = "Seurat",
-                                      enforce_symmetry = enforce_symmetry)
+                                      enforce_symmetry = enforce_symmetry,
+                                      center_on_value = if(symmetry.type == "absolute"){FALSE} else {TRUE},
+                                      value_center = symmetry.center)
         p <- add_scale(p = p,
                        function_use = ggplot2::scale_color_gradientn(colors = colors.gradient,
                                                                      na.value = na.value,
@@ -414,7 +428,7 @@ do_FeaturePlot <- function(sample,
                                                                      limits = scale.setup$limits),
                        scale = "color")
       } else if (num_plots > 1){
-        
+
         feature.use <- features[counter]
         scale.setup <- compute_scales(sample = sample,
                                       feature = feature.use,
@@ -425,7 +439,9 @@ do_FeaturePlot <- function(sample,
                                       min.cutoff = min.cutoff[counter],
                                       max.cutoff = max.cutoff[counter],
                                       flavor = "Seurat",
-                                      enforce_symmetry = enforce_symmetry)
+                                      enforce_symmetry = enforce_symmetry,
+                                      center_on_value = if(symmetry.type == "absolute"){FALSE} else {TRUE},
+                                      value_center = symmetry.center)
 
         p[[counter]] <- add_scale(p = p[[counter]],
                                   function_use = ggplot2::scale_color_gradientn(colors = colors.gradient,
@@ -575,7 +591,9 @@ do_FeaturePlot <- function(sample,
         sample$dummy <- sample@meta.data[, feature]
         ## Or is a gene in the object.
       } else if (feature %in% rownames(sample)){
-        sample$dummy <- .GetAssayData(sample = sample, slot = slot, assay = assay)[feature, ]
+        suppressWarnings({
+        sample$dummy <- SeuratObject::GetAssayData(object = sample, slot = slot, assay = assay)[feature, ]
+        })
         ## Or is a dimensional reduction component.
       } else if (feature %in% dim_colnames){
         # Iterate over each dimensional reduction in the object.
@@ -654,7 +672,9 @@ do_FeaturePlot <- function(sample,
                                       min.cutoff = min.cutoff.use,
                                       max.cutoff = max.cutoff.use,
                                       flavor = "Seurat",
-                                      enforce_symmetry = enforce_symmetry)
+                                      enforce_symmetry = enforce_symmetry,
+                                      center_on_value = if(symmetry.type == "absolute"){FALSE} else {TRUE},
+                                      value_center = symmetry.center)
 
         p.loop <- add_scale(p = p.loop,
                             function_use = ggplot2::scale_color_gradientn(colors = colors.gradient,
@@ -664,7 +684,7 @@ do_FeaturePlot <- function(sample,
                                                                           labels = scale.setup$labels,
                                                                           limits = scale.setup$limits),
                             scale = "color")
-        
+
         p.loop <- p.loop +
                   ggplot2::ggtitle("")
 
@@ -673,15 +693,15 @@ do_FeaturePlot <- function(sample,
           p.loop$layers <- append(base_layer_subset, p.loop$layers)
           p.loop$layers <- append(na_layer, p.loop$layers)
           p.loop$layers <- append(base_layer, p.loop$layers)
-          
+
           suppressMessages({
-            p.loop <- p.loop + 
-              ggplot2::scale_x_continuous(limits = c(min(p.loop$layers[[1]]$data$x), 
-                                                     max(p.loop$layers[[1]]$data$x))) + 
-              ggplot2::scale_y_continuous(limits = c(min(p.loop$layers[[1]]$data$y), 
+            p.loop <- p.loop +
+              ggplot2::scale_x_continuous(limits = c(min(p.loop$layers[[1]]$data$x),
+                                                     max(p.loop$layers[[1]]$data$x))) +
+              ggplot2::scale_y_continuous(limits = c(min(p.loop$layers[[1]]$data$y),
                                                      max(p.loop$layers[[1]]$data$y)))
           })
-          
+
           if (!(is.null(group.by))){
             if (isTRUE(group.by.show.dots)){
               p.loop$layers <- append(p.loop$layers, c(center_layer_2, center_layer_1))
@@ -837,7 +857,9 @@ do_FeaturePlot <- function(sample,
                                         min.cutoff = min.cutoff.use,
                                         max.cutoff = max.cutoff.use,
                                         flavor = "Seurat",
-                                        enforce_symmetry = enforce_symmetry)
+                                        enforce_symmetry = enforce_symmetry,
+                                        center_on_value = if(symmetry.type == "absolute"){FALSE} else {TRUE},
+                                        value_center = symmetry.center)
 
           p.loop <- add_scale(p = p.loop,
                               function_use = ggplot2::scale_color_gradientn(colors = colors.gradient,
@@ -874,15 +896,15 @@ do_FeaturePlot <- function(sample,
             p.loop$layers <- append(base_layer_subset, p.loop$layers)
             p.loop$layers <- append(na_layer, p.loop$layers)
             p.loop$layers <- append(base_layer, p.loop$layers)
-    
+
             suppressMessages({
-              p.loop <- p.loop + 
-                ggplot2::scale_x_continuous(limits = c(min(p.loop$layers[[1]]$data$x), 
-                                                       max(p.loop$layers[[1]]$data$x))) + 
-                ggplot2::scale_y_continuous(limits = c(min(p.loop$layers[[1]]$data$y), 
+              p.loop <- p.loop +
+                ggplot2::scale_x_continuous(limits = c(min(p.loop$layers[[1]]$data$x),
+                                                       max(p.loop$layers[[1]]$data$x))) +
+                ggplot2::scale_y_continuous(limits = c(min(p.loop$layers[[1]]$data$y),
                                                        max(p.loop$layers[[1]]$data$y)))
             })
-            
+
             if (!(is.null(group.by))){
               if (isTRUE(group.by.show.dots)){
                 p.loop$layers <- append(p.loop$layers, c(center_layer_2, center_layer_1))
