@@ -21,7 +21,7 @@
                                  feature_to_rank = "PC_1",
                                  group.by = "seurat_clusters",
                                  continuous_feature = TRUE)
-  } else if (isFALSE(value)){
+  } else if (base::isFALSE(value)){
     message("This function can not be used without its suggested packages.")
     message("Check out which ones are needed using `SCpubr::state_dependencies()`.")
   }
