@@ -14,8 +14,10 @@
     # Default parameters.
     p <- SCpubr::do_ExpressionHeatmap(sample = sample,
                                       features = genes,
-                                      viridis_direction = -1)
-  } else if (isFALSE(value)){
+                                      viridis.direction = -1)
+    
+    p
+  } else if (base::isFALSE(value)){
     message("This function can not be used without its suggested packages.")
     message("Check out which ones are needed using `SCpubr::state_dependencies()`.")
   }
