@@ -25,7 +25,7 @@
                                 features = "EPC1",
                                 split.by = "seurat_clusters")
 
-  } else if (isFALSE(value)){
+  } else if (base::isFALSE(value)){
     message("This function can not be used without its suggested packages.")
     message("Check out which ones are needed using `SCpubr::state_dependencies()`.")
   }
