@@ -18,7 +18,7 @@
     out <- SCpubr::do_FunctionalAnnotationPlot(genes = genes.use,
                                                org.db = org.Hs.eg.db)
 
-  } else if (isFALSE(value)){
+  } else if (base::isFALSE(value)){
     message("This function can not be used without its suggested packages.")
     message("Check out which ones are needed using `SCpubr::state_dependencies()`.")
   }
