@@ -1,11 +1,10 @@
-if (isFALSE(dep_check[["do_CopyNumberVariantPlot"]])){
+if (base::isFALSE(dep_check[["do_CopyNumberVariantPlot"]])){
 
   testthat::test_that("do_BarPlot: CRAN essentials", {
     out <- SCpubr::do_CopyNumberVariantPlot(sample = sample,
                                             infercnv_object = infercnv_object,
                                             using_metacells = FALSE,
-                                            chromosome_locations = human_chr_locations,
-                                            chromosome_focus = "2")
+                                            chromosome_locations = human_chr_locations)
     testthat::expect_type(out, "list")
   })
 
@@ -16,7 +15,57 @@ if (isFALSE(dep_check[["do_CopyNumberVariantPlot"]])){
     out <- SCpubr::do_CopyNumberVariantPlot(sample = sample,
                                             infercnv_object = infercnv_object,
                                             using_metacells = FALSE,
-                                            chromosome_locations = human_chr_locations)
+                                            chromosome_locations = human_chr_locations,
+                                            flip = TRUE)
+    testthat::expect_type(out, "list")
+    
+    out <- SCpubr::do_CopyNumberVariantPlot(sample = sample,
+                                            infercnv_object = infercnv_object,
+                                            using_metacells = FALSE,
+                                            chromosome_locations = human_chr_locations,
+                                            flip = TRUE,
+                                            group.by = c("seurat_clusters", "orig.ident", "annotation"))
+    testthat::expect_type(out, "list")
+    
+    out <- SCpubr::do_CopyNumberVariantPlot(sample = sample,
+                                            infercnv_object = infercnv_object,
+                                            using_metacells = FALSE,
+                                            chromosome_locations = human_chr_locations,
+                                            flip = FALSE)
+    testthat::expect_type(out, "list")
+    
+    out <- SCpubr::do_CopyNumberVariantPlot(sample = sample,
+                                            infercnv_object = infercnv_object,
+                                            using_metacells = FALSE,
+                                            chromosome_locations = human_chr_locations,
+                                            flip = FALSE,
+                                            group.by = c("seurat_clusters", "orig.ident", "annotation"))
+    testthat::expect_type(out, "list")
+    
+    out <- SCpubr::do_CopyNumberVariantPlot(sample = sample,
+                                            infercnv_object = infercnv_object,
+                                            using_metacells = FALSE,
+                                            chromosome_locations = human_chr_locations,
+                                            flip = FALSE,
+                                            return_object = TRUE)
+    testthat::expect_type(out, "list")
+    
+    
+    out <- SCpubr::do_CopyNumberVariantPlot(sample = sample,
+                                            infercnv_object = infercnv_object,
+                                            using_metacells = FALSE,
+                                            group.by = c("seurat_clusters", "orig.ident"),
+                                            chromosome_locations = human_chr_locations,
+                                            flip = TRUE)
+    testthat::expect_type(out, "list")
+    
+    out <- SCpubr::do_CopyNumberVariantPlot(sample = sample,
+                                            infercnv_object = infercnv_object,
+                                            using_metacells = FALSE,
+                                            group.by = c("seurat_clusters", "orig.ident"),
+                                            chromosome_locations = human_chr_locations,
+                                            flip = FALSE,
+                                            return_object = TRUE)
     testthat::expect_type(out, "list")
   })
 
@@ -26,7 +75,6 @@ if (isFALSE(dep_check[["do_CopyNumberVariantPlot"]])){
     out <- SCpubr::do_CopyNumberVariantPlot(sample = sample,
                                             infercnv_object = infercnv_object,
                                             using_metacells = FALSE,
-                                            chromosome_focus = "2",
                                             chromosome_locations = human_chr_locations)
     testthat::expect_type(out, "list")
   })
@@ -42,17 +90,7 @@ if (isFALSE(dep_check[["do_CopyNumberVariantPlot"]])){
     testthat::expect_type(out, "list")
   })
 
-  testthat::test_that("do_BarPlot: PASS - metacells one chromosome", {
-    testthat::skip_on_cran()
-
-    out <- SCpubr::do_CopyNumberVariantPlot(sample = sample,
-                                            infercnv_object = infercnv_object_metacells,
-                                            using_metacells = TRUE,
-                                            metacell_mapping = metacell_mapping,
-                                            chromosome_focus = "2",
-                                            chromosome_locations = human_chr_locations)
-    testthat::expect_type(out, "list")
-  })
+  
 
   testthat::test_that("do_BarPlot: PASS - group.by", {
     testthat::skip_on_cran()
@@ -61,7 +99,6 @@ if (isFALSE(dep_check[["do_CopyNumberVariantPlot"]])){
                                             infercnv_object = infercnv_object_metacells,
                                             using_metacells = TRUE,
                                             metacell_mapping = metacell_mapping,
-                                            chromosome_focus = "2",
                                             group.by = "orig.ident",
                                             chromosome_locations = human_chr_locations)
     testthat::expect_type(out, "list")
@@ -75,7 +112,6 @@ if (isFALSE(dep_check[["do_CopyNumberVariantPlot"]])){
                                             infercnv_object = infercnv_object_metacells,
                                             using_metacells = TRUE,
                                             metacell_mapping = metacell_mapping,
-                                            chromosome_focus = "2",
                                             legend.position = "right",
                                             legend.title = "test",
                                             chromosome_locations = human_chr_locations)
@@ -85,7 +121,6 @@ if (isFALSE(dep_check[["do_CopyNumberVariantPlot"]])){
                                             infercnv_object = infercnv_object_metacells,
                                             using_metacells = TRUE,
                                             metacell_mapping = metacell_mapping,
-                                            chromosome_focus = "2",
                                             legend.position = "bottom",
                                             chromosome_locations = human_chr_locations)
     testthat::expect_type(out, "list")
@@ -98,7 +133,6 @@ if (isFALSE(dep_check[["do_CopyNumberVariantPlot"]])){
                                             infercnv_object = infercnv_object_metacells,
                                             using_metacells = TRUE,
                                             metacell_mapping = metacell_mapping,
-                                            chromosome_focus = "2",
                                             legend.type = "normal",
                                             chromosome_locations = human_chr_locations)
     testthat::expect_type(out, "list")
@@ -107,30 +141,9 @@ if (isFALSE(dep_check[["do_CopyNumberVariantPlot"]])){
                                             infercnv_object = infercnv_object_metacells,
                                             using_metacells = TRUE,
                                             metacell_mapping = metacell_mapping,
-                                            chromosome_focus = "2",
                                             legend.type = "colorbar",
                                             chromosome_locations = human_chr_locations)
     testthat::expect_type(out, "list")
-
-    out <- SCpubr::do_CopyNumberVariantPlot(sample = sample,
-                                            infercnv_object = infercnv_object_metacells,
-                                            using_metacells = TRUE,
-                                            metacell_mapping = metacell_mapping,
-                                            chromosome_focus = "2",
-                                            legend.type = "colorsteps",
-                                            chromosome_locations = human_chr_locations)
-    testthat::expect_type(out, "list")
-
-    out <- SCpubr::do_CopyNumberVariantPlot(sample = sample,
-                                            infercnv_object = infercnv_object_metacells,
-                                            using_metacells = TRUE,
-                                            metacell_mapping = metacell_mapping,
-                                            chromosome_focus = "2",
-                                            legend.type = "colorsteps",
-                                            chromosome_locations = human_chr_locations,
-                                            min.cutoff = 0.95,
-                                            max.cutoff = 1.05)
-    testthat::expect_type(out, "list")
   })
 }
 
